#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include "hemca.h"

int check_cmd(char *arg) {
  const struct {char *name; int min, key; }
  cmd_table[] = {
    {"START"     ,  3, HEMCA_START  },
    {"STOP"      ,  3, HEMCA_STOP   },
    {"CLEAR"     ,  1, HEMCA_CLEAR  },
    {"TIME"      ,  1, HEMCA_TIME   },
    {"LOST"      ,  1, HEMCA_LOST   },
    {"READ"      ,  1, HEMCA_READ   },
    {"EXIT"      ,  1, HEMCA_EXIT   },
    {""          ,  0, 0            }
  };
  char s[256]; int i, n;
  while (*arg == ' ') arg++;
  for (n = 0; *arg != ' ' && *arg != 0 && *arg != '\n'; arg++)
    s[n++] = ((*arg >= 'a') ? *arg - ' ' : *arg); s[n] = 0;
  for (i = 0; cmd_table[i].key != 0; i++) {
    if (n >= cmd_table[i].min && n <= strlen(cmd_table[i].name))
      if (!strncmp(s, cmd_table[i].name, n)) return cmd_table[i].key;
  }
  return -1;
}

int
main(int argc, char *argv[])
{
  int  i, fd=open(DEVICE, O_RDWR);
  long time, lost;
  char s[256];
  unsigned int hist[HEMCA_CHAN];
  while (fgets(s,256,stdin)) {
    switch (check_cmd(s)) {
    case HEMCA_START:
      ioctl(fd, HEMCA_START, 0L);
      break;
    case HEMCA_STOP:
      ioctl(fd, HEMCA_STOP, 0L);
      break;
    case HEMCA_CLEAR:
      ioctl(fd, HEMCA_CLEAR, 0L);
      break;
    case HEMCA_TIME:
      ioctl(fd, HEMCA_TIME, &time);
      printf("TIME\n%ld\n", time);
      break;
    case HEMCA_LOST:
      ioctl(fd, HEMCA_LOST, &lost);
      printf("LOST\n%ld\n", lost);
      break;
    case HEMCA_READ:
      read(fd, hist, HEMCA_CHAN*sizeof(int));
      puts("HIST");
      for (i=0; i<HEMCA_CHAN; i++) printf(" %d",hist[i]);
      puts("");
      break;
    case HEMCA_EXIT:
      goto EXIT;
    default:
      printf("ERROR\ninvalid input (%s)\n", s);
      break;
    }
  }
 EXIT:
  close(fd);
  exit(0);
}
